/**********************************************************************/
/** This file contains the code to compute DID estimates and run     **/
/**    the estimation procedure over the Monte-Carlo datasets given  **/
/**    the master data, selection mechanism and information about    **/
/**    policy regime: expected or unexpected change. Two alternative **/
/**    sources of variation can be used by changing the options in   **/
/**    MCDID: region and eligibility.                                **/
/**    Routines in here are called by the main program, DID.do.      **/
/**                                                                  **/
/** Monica Costa Dias                                                **/
/** September 2008                                                   **/
/**********************************************************************/



***********************************************************************
** DID estimation procedure                                          **
**                                                                   **
**   need to know: who are the treated after policy change (treated) **
**                 who invests in education (d)                      **
**                 time of the observation (time)                    **
***********************************************************************

cap program drop DID
program define DID

	sum y if treated==1 & time==1             /* average outcome among treated after policy change     */
	scalar EY1a=r(mean)
	sum y if treated==1 & time==0             /* average outcome among treated before policy change    */
	scalar EY1b=r(mean)
	sum y if treated==0 & time==1             /* average outcome among controls after policy change    */
	scalar EY0a=r(mean)
	sum y if treated==0 & time==0             /* average outcome among controls before policy change   */
	scalar EY0b=r(mean)

	sum d if treated==1 & time==1             /* participation rate among treated after policy change  */
	scalar p1a = r(mean)
	sum d if treated==1 & time==0             /* participation rate among treated before policy change */
	scalar p1b = r(mean)

	global AggEffect = (EY1a-EY1b)-(EY0a-EY0b)
	global LATE      = $AggEffect/(p1a-p1b)

end



**************************************************************
** Monte Carlo replications of the DID estimation procedure **
**************************************************************

cap program drop MCDID
program define MCDID


	** Monte-Carlo replications **
	******************************
	forvalues i=1/200 {

		display "MC replication ", `i'


		/* Prepare dataset */
		/*******************/
		local lb = (`i'-1)*$N+1
		local ub = `i'*$N
		qui use $dtafile1 in `lb'/`ub', clear               /*   first after policy period                         */
		qui gen time=1
		qui save DID, replace
		qui use $dtafile0 in `lb'/`ub', clear               /*   and then before policy period                     */
		qui gen time=0
		qui append using DID


		/* Create necessary variables: treated, d */
		/*    If using regional variation         */
		/******************************************/
		qui gen treated = (x==1)                            /* treatment group indicator                           */
		qui gen d       = $d if treated==1 & time==1        /* education among treated after policy change         */
		qui replace d   = d_noS if treated==0 | time==0	    /* education among non-treated or before policy change */


		/* Create necessary variables: treated, d */
		/*    If using eligibility status         */
		/******************************************/
*		qui gen d     = $d if time==1                       /* education after policy change                       */
*		qui replace d = d_noS if time==0                    /* education before policy change                      */
*		qui gen s     = $s if time==1                       /* test score after policy change                      */
*		qui replace s = s_noS if time==1                    /* test score before policy change                     */
*		qui gen treated = (s>=4)                            /* treatment group indicator                           */


		/* Running DID to estimate treatment effects */
		/*********************************************/
		qui gen y = d*ln(y1)+(1-d)*ln(y0)                   /* observed outcome                                    */
		qui DID                                             /* DID estimation routine                              */
		global AggEffect`i' = $AggEffect                    /* storing estimates                                   */
		global LATE`i'      = $LATE

	}


	** Storing estimates **
	***********************
	drop _all
	set obs 200
	gen trial    = _n
	gen DID_agg  = .
	gen DID_LATE = .
	forvalues i=1/200 {
		qui replace DID_agg  = ${AggEffect`i'} if trial == `i'
		qui replace DID_LATE = ${LATE`i'} if trial == `i'
	}

end


